% MACHINE Sensors

:- dec_p_type(sensors_inv1(bool)).
sensors_inv1(General_EV) :-
  General_EV in {false,true}.

:- dec_p_type(sensors_inv2(bool)).
sensors_inv2(Open_EV) :-
  Open_EV in {false,true}.

:- dec_p_type(sensors_inv3(bool)).
sensors_inv3(Close_EV) :-
  Close_EV in {false,true}.

:- dec_p_type(sensors_inv4(bool)).
sensors_inv4(Extend_EV) :-
  Extend_EV in {false,true}.

:- dec_p_type(sensors_inv5(bool)).
sensors_inv5(Retract_EV) :-
  Retract_EV in {false,true}.

:- dec_p_type(sensors_inv6(sp,rpb)).
sensors_inv6(PositionsDG,Gear_extended_ind) :-
  pfun(Gear_extended_ind) &
  dompf(Gear_extended_ind,PositionsDG).

:- dec_p_type(sensors_inv7(sp,rpb)).
sensors_inv7(PositionsDG,Gear_shock_absorber_ind) :-
  pfun(Gear_shock_absorber_ind) &
  dompf(Gear_shock_absorber_ind,PositionsDG).

:- dec_p_type(sensors_inv8(sp,rpb)).
sensors_inv8(PositionsDG,Gear_retracted_ind) :-
  pfun(Gear_retracted_ind) &
  dompf(Gear_retracted_ind,PositionsDG).

:- dec_p_type(sensors_inv9(sp,rpb,rpb)).
sensors_inv9(PositionsDG,Gear_extended_ind,Gear_retracted_ind) :-
  foreach(Po in PositionsDG,[M1,M2],
    dec(Po,pos) &
    dec([M1,M2],bool) &
    neg(M1 = true & M2 = true),
    applyTo(Gear_extended_ind,Po,M1) &
    applyTo(Gear_retracted_ind,Po,M2)
  ).
  
:- dec_p_type(sensors_inv10(sp,rpb)).
sensors_inv10(PositionsDG,Door_closed_ind) :-
  pfun(Door_closed_ind) &
  dompf(Door_closed_ind,PositionsDG).

:- dec_p_type(sensors_inv11(sp,rpb)).
sensors_inv11(PositionsDG,Door_open_ind) :-
  pfun(Door_open_ind) &
  dompf(Door_open_ind,PositionsDG).

:- dec_p_type(sensors_inv12(sp,rpb,rpb)).
sensors_inv12(PositionsDG,Door_closed_ind,Door_open_ind) :-
  foreach(Po in PositionsDG,[M1,M2],
    dec(Po,pos) &
    dec([M1,M2],bool) &
    neg(M1 = true & M2 = true),
    applyTo(Door_closed_ind,Po,M1) &
    applyTo(Door_open_ind,Po,M2)
  ).
  
:- dec_p_type(sensors_inv13(sph,posh)).
sensors_inv13(PositionsHandle,Handle_ind) :-
  Handle_ind in PositionsHandle.

:- dec_p_type(sensors_inv14(sps,poss)).
sensors_inv14(PositionsSwitch,Analogical_switch_ind) :-
  Analogical_switch_ind in PositionsSwitch.

:- dec_p_type(sensors_inv15(bool)).
sensors_inv15(Circuit_pressurized_ind) :-
  Circuit_pressurized_ind in {false,true}.

:- dec_p_type(sensors_inv16(bool)).
sensors_inv16(Gears_locked_down) :-
  Gears_locked_down in {false,true}.

:- dec_p_type(sensors_inv17(bool)).
sensors_inv17(Gears_maneuvering) :-
  Gears_maneuvering in {false,true}.

:- dec_p_type(sensors_inv18(bool,bool,bool,bool,bool)).
sensors_inv18(Open_EV,Close_EV,Extend_EV,Retract_EV,General_EV) :-
  (Open_EV = true
   or
   Close_EV = true
   or
   Extend_EV = true
   or
   Retract_EV = true
  )
    implies
      General_EV = true.

:- dec_p_type(sensors_inv19(bool,bool)).
sensors_inv19(Open_EV,Close_EV) :-
  neg(Open_EV = true & Close_EV = true).

:- dec_p_type(sensors_inv20(bool,bool,bool)).
sensors_inv20(Open_EV,Extend_EV,Retract_EV) :-
  (Extend_EV = true
   or
   Retract_EV = true
  )
    implies
      Open_EV = true.

:- dec_p_type(sensors_inv21(sp,rpb,rpb)).
sensors_inv21(PositionsDG,Gear_shock_absorber_p,Gear_ext_p) :-
  foreach(Po in PositionsDG,[M1,M2],
    dec(Po,pos) &
    dec([M1,M2],bool) &
    (M1 = true implies M2 = true),
    applyTo(Gear_shock_absorber_p,Po,M1) &
    applyTo(Gear_ext_p,Po,M2)
  ).
  
:- dec_p_type(sensors_inv22(bool,bool)).
sensors_inv22(Extend_EV,Retract_EV) :-
  neg(Extend_EV = true & Retract_EV = true).

:- dec_p_type(sensors_inv23(bool)).
sensors_inv23(End_cycle) :-
  End_cycle in {false,true}.

:- dec_p_type(
     sensors_init(sp,rpb,rpb,rpb,rpb,rpb,rpb,bool,rpb,posh,poss,
                  bool,bool,bool,bool,bool,bool,bool,bool,bool,bool,bool,
                  posh,poss,bool,bool,bool,bool,bool,bool,rpb,rpb,rpb,rpb,rpb,
                  bool,bool,bool)).
sensors_init(
    PositionsDG,
    Gear_ext_p,
    Gear_ret_p,
    Door_open_p,
    Door_closed_p,
    Door_cylinder_locked_p,
    Gear_cylinder_locked_p,
    Circuit_pressurized_p,
    Gear_shock_absorber_p,
    Handle_p,
    Analogical_switch_p,
    Intermediate1,
    Intermediate2,
    Handle,
    General_EV_p,
    Open_EV_p,
    Close_EV_p,
    Extend_EV_p,
    Retract_EV_p,
    GreenLight_p,
    OrangeLight_p,
    RedLight_p,
    Handle_ind,
    Analogical_switch_ind,
    Circuit_pressurized_ind,
    General_EV,
    Open_EV,
    Close_EV,
    Extend_EV,
    Retract_EV,
    Gear_extended_ind,
    Gear_shock_absorber_ind,
    Gear_retracted_ind,
    Door_closed_ind,
    Door_open_ind,
    Gears_locked_down,
    Gears_maneuvering,
    End_cycle
) :-
  Gear_ext_p = cp(PositionsDG,{true}) &
  Gear_ret_p = cp(PositionsDG,{false}) &
  Door_open_p = cp(PositionsDG,{false}) &
  Door_closed_p = cp(PositionsDG,{true}) &
  Door_cylinder_locked_p = cp(PositionsDG,{true}) &
  Gear_cylinder_locked_p = cp(PositionsDG,{true}) &
  Circuit_pressurized_p = false &
  Gear_shock_absorber_p = cp(PositionsDG,{true}) &
  Handle_p = down &
  Analogical_switch_p = open &
  Intermediate1 = false &
  Intermediate2 = false &
  Handle = false &
  General_EV_p = false &
  Open_EV_p = false &
  Close_EV_p = false &
  Extend_EV_p = false &
  Retract_EV_p = false &
  GreenLight_p = true &
  OrangeLight_p = false &
  RedLight_p = false &
  Gear_extended_ind = cp(PositionsDG,{true}) &
  Gear_shock_absorber_ind = cp(PositionsDG,{true}) &
  Gear_retracted_ind = cp(PositionsDG,{false}) &
  Door_closed_ind = cp(PositionsDG,{true}) &
  Door_open_ind = cp(PositionsDG,{false}) &
  General_EV = false &
  Open_EV = false &
  Close_EV = false &
  Extend_EV = false &
  Retract_EV = false &
  Handle_ind = down &
  Analogical_switch_ind = open &
  Circuit_pressurized_ind = false &
  Gears_locked_down = true &
  Gears_maneuvering = false &
  End_cycle = true.

:- dec_p_type(sensors_start_GearExtend(sp,rpb,rpb,rpb,bool,bool,bool,rpb)).
sensors_start_GearExtend(
    PositionsDG,
    Gear_ret_p,
    Door_open_p,
    Gear_cylinder_locked_p,
    Extend_EV_p,
    Retract_EV_p,
    Circuit_pressurized_p,
    Gear_ret_p_
) :-
  dec(Po,pos) &
  Po in PositionsDG &
  applyTo(Gear_ret_p,Po,true) &
  Door_open_p = cp(PositionsDG,{true}) &
  applyTo(Gear_cylinder_locked_p,Po,false) &
  Circuit_pressurized_p = false &
  Extend_EV_p = true &
  Retract_EV_p = false &
  foplus(Gear_ret_p,Po,false,Gear_ret_p_).

:- dec_p_type(sensors_make_GearExtended(sp,rpb,bool,bool,bool,rpb,rpb)).
sensors_make_GearExtended(
    PositionsDG,
    Gear_ext_p,
    Circuit_pressurized_p,
    Extend_EV_p,
    Retract_EV_p,
    Gear_ret_p,
    Gear_ext_p_
) :-
  dec(Po,pos) &
  Po in PositionsDG &
  applyTo(Gear_ext_p,Po,false) &
  applyTo(Gear_ret_p,Po,false) &
  Circuit_pressurized_p = true &
  Extend_EV_p = true &
  Retract_EV_p = false &
  foplus(Gear_ext_p,Po,true,Gear_ext_p_).

:- dec_p_type(
     sensors_start_GearRetract(sp,rpb,rpb,rpb,rpb,bool,bool,bool,rpb,rpb)).
sensors_start_GearRetract(
    PositionsDG,
    Gear_ext_p,
    Door_open_p,
    Gear_shock_absorber_p,
    Gear_cylinder_locked_p,
    Circuit_pressurized_p,
    Extend_EV_p,
    Retract_EV_p,
    Gear_ext_p_,
    Gear_shock_absorber_p_
) :-
  dec(Po,pos) &
  Po in PositionsDG &
  applyTo(Gear_ext_p,Po,true) &
  Door_open_p = cp(PositionsDG,{true}) &
  applyTo(Gear_cylinder_locked_p,Po,false) &
  Circuit_pressurized_p = true &
  Extend_EV_p = true &
  Retract_EV_p = false &
  foplus(Gear_ext_p,Po,false,Gear_ext_p_) &
  foplus(Gear_shock_absorber_p,Po,false,Gear_shock_absorber_p_).

:- dec_p_type(sensors_make_GearRetracted(sp,rpb,rpb,bool,bool,bool,rpb)).
sensors_make_GearRetracted(
    PositionsDG,
    Gear_ext_p,
    Gear_ret_p,
    Circuit_pressurized_p,
    Extend_EV_p,
    Retract_EV_p,
    Gear_ret_p_
) :-
  dec(Po,pos) &
  Po in PositionsDG &
  applyTo(Gear_ext_p,Po,false) &
  applyTo(Gear_ret_p,Po,false) &
  Circuit_pressurized_p = true &
  Extend_EV_p = true &
  Retract_EV_p = false &
  foplus(Gear_ret_p,Po,true,Gear_ret_p_).

:- dec_p_type(sensors_start_DoorOpening(rpb,rpb,bool,bool,bool,rpb)).
sensors_start_DoorOpening(
    Door_closed_p,
    Door_cylinder_locked_p,
    Circuit_pressurized_p,
    Open_EV_p,
    Close_EV_p,
    Door_closed_p_
) :-
  dec(Po,pos) &
  applyTo(Door_closed_p,Po,true) &
  applyTo(Door_cylinder_locked_p,Po,false) &
  Circuit_pressurized_p = true &
  Open_EV_p = true &
  Close_EV_p = false &
  foplus(Door_closed_p,Po,false,Door_closed_p_).

:- dec_p_type(sensors_make_DoorOpen(rpb,rpb,bool,bool,bool,rpb)).
sensors_make_DoorOpen(
    Door_open_p,
    Door_closed_p,
    Circuit_pressurized_p,
    Open_EV_p,
    Close_EV_p,
    Door_open_p_
) :-
  dec(Po,pos) &
  applyTo(Door_open_p,Po,false) &
  applyTo(Door_closed_p,Po,false) &
  Circuit_pressurized_p = true &
  Open_EV_p = true &
  Close_EV_p = false &
  foplus(Door_open_p,Po,true,Door_open_p_).

:- dec_p_type(sensors_start_DoorClosing(sp,rpb,rpb,rpb,rpb,bool,bool,bool,rpb)).
sensors_start_DoorClosing(
    PositionsDG,
    Gear_ext_p,
    Gear_ret_p,
    Door_open_p,
    Gear_cylinder_locked_p,
    Circuit_pressurized_p,
    Open_EV_p,
    Close_EV_p,
    Door_open_p_
) :-
  dec(Po,pos) &
  Po in PositionsDG &
  applyTo(Door_open_p,Po,true) &
  Gear_ext_p = cp(PositionsDG,{true}) &
  Gear_ret_p = cp(PositionsDG,{true}) &
  Gear_cylinder_locked_p = cp(PositionsDG,{true}) &
  Circuit_pressurized_p = true &
  Close_EV_p = true &
  Open_EV_p = false &
  foplus(Door_open_p,Po,false,Door_open_p_).

:- dec_p_type(sensors_make_DoorClosed(rpb,rpb,bool,bool,bool,rpb)).
sensors_make_DoorClosed(
    Door_open_p,
    Door_closed_p,
    Circuit_pressurized_p,
    Open_EV_p,
    Close_EV_p,
    Door_closed_p_
) :-
  dec(Po,pos) &
  applyTo(Door_closed_p,Po,false) &
  applyTo(Door_open_p,Po,false) &
  Circuit_pressurized_p = true &
  Close_EV_p = true &
  Open_EV_p = false &
  foplus(Door_closed_p,Po,true,Door_closed_p_).

:- dec_p_type(sensors_UnlockGearCylinder(sp,rpb,rpb,rpb,rpb,bool,bool,bool,rpb)).
sensors_UnlockGearCylinder(
    PositionsDG,
    Gear_ext_p,
    Gear_ret_p,
    Door_open_p,
    Gear_cylinder_locked_p,
    Circuit_pressurized_p,
    Extend_EV_p,
    Retract_EV_p,
    Gear_cylinder_locked_p_
) :-
  dec(Po,pos) &
  Po in PositionsDG &
  applyTo(Gear_cylinder_locked_p,Po,true) &
  (applyTo(Gear_ext_p,Po,true)
   or
   applyTo(Gear_ret_p,Po,true)
  ) &
  Door_open_p = cp(PositionsDG,{true}) &
  Circuit_pressurized_p = true &
  (applyTo(Gear_ext_p,Po,true) &
   Retract_EV_p = true
   or
   applyTo(Gear_ret_p,Po,true) &
   Extend_EV_p = true
  ) &
  foplus(Gear_cylinder_locked_p,Po,true,Gear_cylinder_locked_p_).

:- dec_p_type(sensors_LockGearCylinder(sp,rpb,rpb,rpb,bool,bool,bool,rpb)).
sensors_LockGearCylinder(
    PositionsDG,
    Gear_ext_p,
    Gear_ret_p,
    Gear_cylinder_locked_p,
    Circuit_pressurized_p,
    Extend_EV_p,
    Retract_EV_p,
    Gear_cylinder_locked_p_
) :-
  dec(Po,pos) &
  Po in PositionsDG &
  applyTo(Gear_cylinder_locked_p,Po,false) &
  (applyTo(Gear_ext_p,Po,true)
   or
   applyTo(Gear_ret_p,Po,true)
  ) &
  Circuit_pressurized_p = true &
  (applyTo(Gear_ext_p,Po,true) &
   Extend_EV_p = true
   or
   applyTo(Gear_ret_p,Po,true) &
   Retract_EV_p = true
  ) &
  foplus(Gear_cylinder_locked_p,Po,true,Gear_cylinder_locked_p_).

:- dec_p_type(sensors_UnlockDoorCylinder(sp,rpb,rpb,bool,bool,bool,rpb)).
sensors_UnlockDoorCylinder(
    PositionsDG,
    Door_closed_p,
    Door_cylinder_locked_p,
    Circuit_pressurized_p,
    Open_EV_p,
    Close_EV_p,
    Door_cylinder_locked_p_
) :-
  dec(Po,pos) &
  Po in PositionsDG &
  applyTo(Door_closed_p,Po,true) &
  applyTo(Door_cylinder_locked_p,Po,true) &
  Circuit_pressurized_p = true &
  Open_EV_p = true &
  Close_EV_p = false &
  foplus(Door_cylinder_locked_p,Po,false,Door_cylinder_locked_p_).

:- dec_p_type(sensors_LockDoorCylinder(sp,rpb,rpb,bool,bool,bool,rpb)).
sensors_LockDoorCylinder(
    PositionsDG,
    Door_closed_p,
    Door_cylinder_locked_p,
    Circuit_pressurized_p,
    Open_EV_p,
    Close_EV_p,
    Door_cylinder_locked_p_
) :-
  dec(Po,pos) &
  Po in PositionsDG &
  applyTo(Door_cylinder_locked_p,Po,false) &
  applyTo(Door_closed_p,Po,true) &
  Circuit_pressurized_p = true &
  Close_EV_p = true &
  Open_EV_p = false &
  foplus(Door_cylinder_locked_p,Po,true,Door_cylinder_locked_p_).

:- dec_p_type(sensors_Pressurize_HydrolicCircuit(bool,bool,bool)).
sensors_Pressurize_HydrolicCircuit(
    Circuit_pressurized_p,
    General_EV_p,
    Circuit_pressurized_p_
) :-
  Circuit_pressurized_p = false &
  General_EV_p = true &
  Circuit_pressurized_p_ = true.

:- dec_p_type(sensors_Unpressurize_HydrolicCircuit(bool,bool,bool)).
sensors_Unpressurize_HydrolicCircuit(
    Circuit_pressurized_p,
    General_EV_p,
    Circuit_pressurized_p_
) :-
  Circuit_pressurized_p = true &
  General_EV_p = false &
  Circuit_pressurized_p_ = false.

:- dec_p_type(sensors_MakeGearShockAbsorberFalse(sp,rpb,rpb)).
sensors_MakeGearShockAbsorberFalse(
    PositionsDG,
    Gear_shock_absorber_p,
    Gear_shock_absorber_p_
) :-
  dec(Po,pos) &
  Po in PositionsDG &
  applyTo(Gear_shock_absorber_p,Po,true) &
  foplus(Gear_shock_absorber_p,Po,false,Gear_shock_absorber_p_).

:- dec_p_type(sensors_MakeGearShockAbsorberTRUE(sp,rpb,rpb,posh,bool,rpb)).
sensors_MakeGearShockAbsorberTRUE(
    PositionsDG,
    Gear_ext_p,
    Gear_shock_absorber_p,
    Handle_p,
    GreenLight_p,
    Gear_shock_absorber_p_
) :-
  dec(Po,pos) &
  Po in PositionsDG &
  applyTo(Gear_shock_absorber_p,Po,false) &
  applyTo(Gear_ext_p,Po,true) &
  Handle_p = down &
  GreenLight_p = true &
  foplus(Gear_shock_absorber_p,Po,true,Gear_shock_absorber_p_).

:- dec_p_type(sensors_MakeGeneralValveActive(bool,bool,bool)).
sensors_MakeGeneralValveActive(
    General_EV_p,
    General_EV,
    General_EV_p_
) :-
  General_EV_p = false &
  General_EV = true &
  General_EV_p_ = true.

:- dec_p_type(sensors_MakeGeneralValveNoActive(bool,bool,bool)).
sensors_MakeGeneralValveNoActive(
    General_EV_p,
    General_EV,
    General_EV_p_
) :-
  General_EV_p = true &
  General_EV = false &
  General_EV_p_ = false.

:- dec_p_type(sensors_MakeOpenDoorValveActive(bool,bool,bool,bool)).
sensors_MakeOpenDoorValveActive(
    Circuit_pressurized_p,
    Open_EV_p,
    Open_EV,
    Open_EV_p_
) :-
  Open_EV_p = false &
  Circuit_pressurized_p = true &
  Open_EV = true &
  Open_EV_p_ = true.
  
:- dec_p_type(sensors_MakeOpenDoorValveNoActive(bool,bool,bool)).
sensors_MakeOpenDoorValveNoActive(
    Open_EV_p,
    Open_EV,
    Open_EV_p_
) :-
  Open_EV_p = true &
  Open_EV = false &
  Open_EV_p_ = false.
  
:- dec_p_type(sensors_MakeCloseDoorValveActive(bool,bool,bool,bool)).
sensors_MakeCloseDoorValveActive(
    Circuit_pressurized_p,
    Close_EV_p,
    Close_EV,
    Close_EV_p_
) :-
  Close_EV_p = false &
  Circuit_pressurized_p = true &
  Close_EV = true &
  Close_EV_p_ = true.
  
:- dec_p_type(sensors_MakeCloseDoorValveNoActive(bool,bool,bool)).
sensors_MakeCloseDoorValveNoActive(
    Close_EV_p,
    Close_EV,
    Close_EV_p_
) :-
  Close_EV_p = true &
  Close_EV = false &
  Close_EV_p_ = false.
  
:- dec_p_type(sensors_MakeExtendGearValveActive(bool,bool,bool,bool)).
sensors_MakeExtendGearValveActive(
    Circuit_pressurized_p,
    Extend_EV_p,
    Extend_EV,
    Extend_EV_p_
) :-
  Extend_EV_p = false &
  Circuit_pressurized_p = true &
  Extend_EV = true &
  Extend_EV_p_ = true.
  
:- dec_p_type(sensors_MakeExtendGearValveNoActive(bool,bool,bool)).
sensors_MakeExtendGearValveNoActive(
    Extend_EV_p,
    Extend_EV,
    Extend_EV_p_
) :-
  Extend_EV_p = true &
  Extend_EV = false &
  Extend_EV_p_ = false.
  
:- dec_p_type(sensors_MakeRetractGearValveActive(bool,bool,bool,bool)).
sensors_MakeRetractGearValveActive(
    Circuit_pressurized_p,
    Retract_EV_p,
    Retract_EV,
    Retract_EV_p_
) :-
  Retract_EV_p = false &
  Circuit_pressurized_p = true &
  Retract_EV = true &
  Retract_EV_p_ = true.
  
:- dec_p_type(sensors_MakeRetractGearValveNoActive(bool,bool,bool)).
sensors_MakeRetractGearValveNoActive(
    Retract_EV_p,
    Retract_EV,
    Retract_EV_p_
) :-
  Retract_EV_p = true &
  Retract_EV = false &
  Retract_EV_p_ = false.
  
:- dec_p_type(sensors_PutHandleUp(posh,posh,bool)).
sensors_PutHandleUp(
    Handle_p,
    Handle_p_,
    Handle_
) :-
  Handle_p = down &
  Handle_p_ = up &
  Handle_ = true.

:- dec_p_type(sensors_PutHandleDown(posh,bool,posh,bool)).
sensors_PutHandleDown(
    Handle_p,
    GreenLight_p,
    Handle_p_,
    Handle_
) :-
  Handle_p = up &
  GreenLight_p = false &
  Handle_p_ = down &
  Handle_ = true.

:- dec_p_type(sensors_close_Switch(bool,poss,bool)).
sensors_close_Switch(
    Intermediate1,
    Analogical_switch_p_,
    Intermediate1_
) :-
  Intermediate1 = true &
  Analogical_switch_p_ = closed &
  Intermediate1_ = false.

:- dec_p_type(sensors_HandleOnClosed(poss,bool,bool)).
sensors_HandleOnClosed(
    Analogical_switch_p,
    Handle,
    Handle_
) :-
  Analogical_switch_p = closed &
  Handle = true &
  Handle_ = false.

:- dec_p_type(sensors_FromCloseToIntermediate2(poss,poss,bool)).
sensors_FromCloseToIntermediate2(
    Analogical_switch_p,
    Analogical_switch_p_,
    Intermediate2_
) :-
  Analogical_switch_p = closed &
  Intermediate2_ = true &
  Analogical_switch_p_ = open.

:- dec_p_type(
     sensors_HandleFromOpenToIntermediate1(poss,bool,bool,bool,bool,bool)).
sensors_HandleFromOpenToIntermediate1(
    Analogical_switch_p,
    Intermediate1,
    Intermediate2,
    Handle,
    Intermediate1_,
    Handle_
) :-
  Analogical_switch_p = open &
  Intermediate1 = false &
  Intermediate2 = false &
  Handle = true &
  Intermediate1_ = true &
  Handle_ = false.

:- dec_p_type(
     sensors_HandleFromIntermediate2ToIntermediate1(bool,bool,bool,bool,bool)).
sensors_HandleFromIntermediate2ToIntermediate1(
    Intermediate2,
    Handle,
    Intermediate1_,
    Intermediate2_,
    Handle_
) :-
  Intermediate2 = true &
  Handle = true &
  Handle_ = false &
  Intermediate2_ = false &
  Intermediate1_ = true.

:- dec_p_type(sensors_ReadHandleSwitchCircuit(sph,sps,posh,poss,bool,bool)).
sensors_ReadHandleSwitchCircuit(
    PositionsHandle,
    PositionsSwitch,
    Handle_ind_,
    Analogical_switch_ind_,
    Circuit_pressurized_ind_,
    End_cycle_
) :-
  dec(Handle_sensor_value,posh) &
  dec(Analogical_switch_sensor_value,poss) &
  dec(Circuit_pressurized_sensor_value,bool) &
  Handle_sensor_value in PositionsHandle &
  Analogical_switch_sensor_value in PositionsSwitch &
  Handle_ind_ = Handle_sensor_value &
  Analogical_switch_ind_ = Analogical_switch_sensor_value &
  Circuit_pressurized_ind_ = Circuit_pressurized_sensor_value &
  End_cycle_ = false.

:- dec_p_type(
     sensors_ReadGearsShock(rpb,rpb,rpb,rpb,rpb,rpb,rpb,bool,bool,bool)).
sensors_ReadGearsShock(
    Gear_ext_p,
    Gear_ret_p,
    Gear_cylinder_locked_p,
    Gear_shock_absorber_p,
    Gear_extended_ind_,
    Gear_retracted_ind_,
    Gear_shock_absorber_ind_,
    Gears_locked_down_,
    Gears_maneuvering_,
    End_cycle_
) :-
  dec([Gear_extended_sensor_valueF,
       Gear_extended_sensor_valueL,
       Gear_extended_sensor_valueR,
       Gear_retracted_sensor_valueF,
       Gear_retracted_sensor_valueL,
       Gear_retracted_sensor_valueR,
       Gear_shock_absorber_sensor_valueF,
       Gear_shock_absorber_sensor_valueL,
       Gear_shock_absorber_sensor_valueR],bool) &
  (Gear_extended_sensor_valueF = true
     implies
       applyTo(Gear_ext_p,front,true) &
       applyTo(Gear_cylinder_locked_p,front,true)
  ) &
  (Gear_extended_sensor_valueL = true
     implies
       applyTo(Gear_ext_p,left,true) &
       applyTo(Gear_cylinder_locked_p,left,true)
  ) &
  (Gear_extended_sensor_valueR = true
     implies
       applyTo(Gear_ext_p,right,true) &
       applyTo(Gear_cylinder_locked_p,right,true)
  ) &
  (Gear_retracted_sensor_valueF = true
     implies
       applyTo(Gear_ret_p,front,true) &
       applyTo(Gear_cylinder_locked_p,front,true)
  ) &
  (Gear_retracted_sensor_valueL = true
     implies
       applyTo(Gear_ret_p,left,true) &
       applyTo(Gear_cylinder_locked_p,left,true)
  ) &
  (Gear_retracted_sensor_valueR = true
     implies
       applyTo(Gear_ret_p,right,true) &
       applyTo(Gear_cylinder_locked_p,right,true)
  ) &
  (Gear_shock_absorber_sensor_valueF = false
     implies
       applyTo(Gear_shock_absorber_p,front,false)
  ) &
  (Gear_shock_absorber_sensor_valueL = false
     implies
       applyTo(Gear_shock_absorber_p,left,false)
  ) &
  Gear_extended_ind_ = 
    {[front,Gear_extended_sensor_valueF],
     [left,Gear_extended_sensor_valueL],
     [right,Gear_extended_sensor_valueR]} &
  Gear_retracted_ind_ = 
    {[front,Gear_retracted_sensor_valueF],
     [left,Gear_retracted_sensor_valueL],
     [right,Gear_retracted_sensor_valueR]} &
  Gear_shock_absorber_ind_ = 
    {[front,Gear_shock_absorber_sensor_valueF],
     [left,Gear_shock_absorber_sensor_valueL],
     [right,Gear_shock_absorber_sensor_valueR]} &
  bool(
    Gears_locked_down_,
    Gear_extended_sensor_valueF = true &
    Gear_extended_sensor_valueL = true &
    Gear_extended_sensor_valueR = true
  ) &
  bool(
    Gears_maneuvering_,
    Gear_extended_sensor_valueF = false &
    Gear_retracted_sensor_valueF = false
    or
    Gear_extended_sensor_valueL = false &
    Gear_retracted_sensor_valueL = false
    or
    Gear_extended_sensor_valueR = false &
    Gear_retracted_sensor_valueR = false
  ) &
  End_cycle_ = false.

:- dec_p_type(sensors_ReadDoors(rpb,rpb,rpb,rpb,bool)).
sensors_ReadDoors(
    Door_open_p,
    Door_closed_p,
    Door_open_ind_,
    Door_closed_ind_,
    End_cycle_
) :-
  dec([Door_open_sensor_valueF,
       Door_open_sensor_valueL,
       Door_open_sensor_valueR,
       Door_closed_sensor_valueF,
       Door_closed_sensor_valueL,
       Door_closed_sensor_valueR],bool) &
  (Door_open_sensor_valueF = true implies applyTo(Door_open_p,front,true)) &
  (Door_open_sensor_valueL = true implies applyTo(Door_open_p,left,true)) &
  (Door_open_sensor_valueR = true implies applyTo(Door_open_p,right,true)) &
  (Door_closed_sensor_valueF = true implies applyTo(Door_closed_p,front,true)) &
  (Door_closed_sensor_valueL = true implies applyTo(Door_closed_p,left,true)) &
  (Door_closed_sensor_valueR = true implies applyTo(Door_closed_p,right,true)) &
  Door_open_ind_ = 
    {[front,Door_open_sensor_valueF],
     [left,Door_open_sensor_valueL],
     [right,Door_open_sensor_valueR]} &
  Door_closed_ind_ = 
    {[front,Door_closed_sensor_valueF],
     [left,Door_closed_sensor_valueL],
     [right,Door_closed_sensor_valueR]} &
  End_cycle_ = false.

:- dec_p_type(sensors_open_Switch(bool,bool)).
sensors_open_Switch(
    Intermediate2,
    Intermediate2_
) :-
  Intermediate2 = true &
  Intermediate2_ = false.

:- dec_p_type(sensors_MakeGreenLightActive(bool,bool,bool)).
sensors_MakeGreenLightActive(
    GreenLight_p,
    Gears_locked_down,
    GreenLight_p_
) :-
  GreenLight_p = false &
  Gears_locked_down = true &
  GreenLight_p_ = true.
  
:- dec_p_type(sensors_MakeGreenLightNoActive(bool,bool,bool)).
sensors_MakeGreenLightNoActive(
    GreenLight_p,
    Gears_locked_down,
    GreenLight_p_
) :-
  GreenLight_p = true &
  Gears_locked_down = false &
  GreenLight_p_ = false.
  
:- dec_p_type(sensors_MakeOrangeLightActive(bool,bool,bool)).
sensors_MakeOrangeLightActive(
    OrangeLight_p,
    Gears_maneuvering,
    OrangeLight_p_
) :-
  OrangeLight_p = false &
  Gears_maneuvering = true &
  OrangeLight_p_ = true.
  
:- dec_p_type(sensors_MakeOrangeLightNoActive(bool,bool,bool)).
sensors_MakeOrangeLightNoActive(
    OrangeLight_p,
    Gears_maneuvering,
    OrangeLight_p_
) :-
  OrangeLight_p = true &
  Gears_maneuvering neq true &
  OrangeLight_p_ = false.
  
:- dec_p_type(sensors_MakeRedLightActive(bool,bool)).
sensors_MakeRedLightActive(
    RedLight_p,
    RedLight_p_
) :-
  RedLight_p = false &
  RedLight_p_ = true.
  
:- dec_p_type(
     sensors_OutputGEV(sp,poss,posh,rpb,rpb,bool,bool,bool,rpb,bool,bool)).
sensors_OutputGEV(
    PositionsDG,
    Analogical_switch_ind,
    Handle_ind,
    Gear_extended_ind,
    Gear_retracted_ind,
    Open_EV,
    Close_EV,
    General_EV,
    Door_closed_ind,
    General_EV_,
    End_cycle_
) :-
  dec(General_EV_value,bool) &
  bool(
    General_EV_value,
    Analogical_switch_ind = closed &
    (Handle_ind = down & 
     Gear_extended_ind neq cp(PositionsDG,{true})
     or
     Handle_ind = up &
     Gear_retracted_ind neq cp(PositionsDG,{true})
    )
    or
    Door_closed_ind neq cp(PositionsDG,{true})
    or
    Open_EV = true 
    or
    Close_EV = true
  ) &
  General_EV_value neq General_EV &
  General_EV_ = General_EV_value &
  End_cycle_ = true.

:- dec_p_type(
     sensors_OutputOpenEV(sp,bool,bool,bool,bool,bool,posh,rpb,rpb,bool,bool)).
sensors_OutputOpenEV(
    PositionsDG,
    Close_EV,
    Open_EV,
    General_EV,
    Extend_EV,
    Retract_EV,
    Handle_ind,
    Gear_retracted_ind,
    Gear_extended_ind,
    Open_EV_,
    End_cycle_
) :-
  dec(Open_EV_value,bool) &
  bool(
    Open_EV_value,
    Close_EV = false &
    General_EV = true &
    (Handle_ind = up &
     Gear_retracted_ind neq cp(PositionsDG,{true})
     or
     Handle_ind = down &
     Gear_extended_ind neq cp(PositionsDG,{true})
    )
    or
    Extend_EV = true 
    or
    Retract_EV = true
  ) &
  Open_EV neq Open_EV_value &
  Open_EV_ = Open_EV_value &
  End_cycle_ = true.

:- dec_p_type(
     sensors_OutputCloseEv(
       sp,posh,rpb,rpb,rpb,bool,bool,bool,bool,bool,bool,bool)).
sensors_OutputCloseEv(
    PositionsDG,
    Handle_ind,
    Gear_retracted_ind,
    Gear_extended_ind,
    Door_closed_ind,
    General_EV,
    Extend_EV,
    Retract_EV,
    Open_EV,
    Close_EV,
    Close_EV_,
    End_cycle_
) :-
  dec(Close_EV_value,bool) &
  bool(
    Close_EV_value,
    (Handle_ind = up &
     Gear_retracted_ind = cp(PositionsDG,{true})
     or
     Handle_ind = down &
     Gear_extended_ind = cp(PositionsDG,{true})
    ) &
    Door_closed_ind neq cp(PositionsDG,{true}) &
    General_EV = true &
    Extend_EV = false &
    Retract_EV = false &
    Open_EV = false
  ) &
  Close_EV neq Close_EV_value &
  Close_EV_ = Close_EV_value &
  End_cycle_ = true.

:- dec_p_type(sensors_OutputExtendEV(sp,posh,rpb,rpb,bool,bool,bool,bool,bool)).
sensors_OutputExtendEV(
    PositionsDG,
    Handle_ind,
    Gear_extended_ind,
    Door_open_ind,
    Open_EV,
    Retract_EV,
    Extend_EV,
    Extend_EV_,
    End_cycle_
) :-
  dec(Extend_EV_value,bool) &
  bool(
    Extend_EV_value,
    Handle_ind = down &
    Gear_extended_ind neq cp(PositionsDG,{true}) &
    Open_EV = true &
    Door_open_ind = cp(PositionsDG,{true}) &
    Retract_EV = false
  ) &
  Extend_EV neq Extend_EV_value &
  Extend_EV_ = Extend_EV_value &
  End_cycle_ = true.

:- dec_p_type(
     sensors_OutputRetractEV(sp,posh,rpb,rpb,rpb,bool,bool,bool,bool,bool)).
sensors_OutputRetractEV(
    PositionsDG,
    Handle_ind,
    Gear_retracted_ind,
    Door_open_ind,
    Gear_shock_absorber_ind,
    Open_EV,
    Extend_EV,
    Retract_EV,
    Retract_EV_,
    End_cycle_
) :-
  dec(Retract_EV_value,bool) &
  bool(
    Retract_EV_value,
    Handle_ind = up &
    Gear_retracted_ind neq cp(PositionsDG,{true}) &
    Open_EV = true &
    Extend_EV = false &
    Door_open_ind = cp(PositionsDG,{true}) &
    Gear_shock_absorber_ind = cp(PositionsDG,{false})
  ) &
  Retract_EV neq Retract_EV_value &
  Retract_EV_ = Retract_EV_value &
  End_cycle_ = true.

